==> johnny-five-0.1.901.tgz: package/docs/servo-array.md <==
# Servo Array

```javascript
var five = require("../lib/johnny-five.js"),
    board, servos, array;

board = new five.Board({
  debug: true
});

board.on("ready", function() {

  servos = {
    a: new five.Servo(9),
    b: new five.Servo(10)
  };

  array = five.Servo.Array();

  // Inject the `servo` hardware into
  // the Repl instance's context;
  // allows direct command line access
  board.repl.inject({
    array: array
  });

  // console.log( array );

  // Servo.Array API

  // center()
  //
  // centers all servos to 90deg
  //
  array.center();


  // min()
  //
  // set all servos to the minimum degrees
  // defaults to 0
  //
  // eg. array.min();

  // max()
  //
  // set all servos to the maximum degrees
  // defaults to 180
  //
  // eg. array.max();

  // stop()
  //
  // stop all servos
  //
  // eg. array.stop();

  // each( callbackFn )
  //
  // Execute callbackFn for each active servo instance
  //
  // eg.
  // array.each(function( servo, index ) {
  //
  //  `this` refers to the current servo instance
  //
  // });

});

```

## Breadboard




## Documentation

_(Nothing yet)_









## Contributing
All contributions must adhere to the the [Idiomatic.js Style Guide](https://github.com/rwldrn/idiomatic.js),
by maintaining the existing coding style. Add unit tests for any new or changed functionality. Lint and test your code using [grunt](https://github.com/cowboy/grunt).

## Release History
_(Nothing yet)_

## License
Copyright (c) 2012 Rick Waldron <waldron.rick@gmail.com>
Licensed under the MIT license.

==> johnny-five-0.1.950.tgz: package/docs/servo-array.md <==
# Servo Array

```javascript
var five = require("../lib/johnny-five.js"),
    board, array;

board = new five.Board({
  debug: true
});

board.on("ready", function() {

  five.Servo({
    pin: 9,
    // Limit this servo to 170°
    range: [ 0, 170 ]
  });

  five.Servo(10);

  // Initialize a reference to all Servo instances
  // five.Servo.Array()
  // five.Servos()
  array = five.Servos();

  // Inject the `servo` hardware into
  // the Repl instance's context;
  // allows direct command line access
  board.repl.inject({
    array: array
  });


  // Servo.Array API

  // center()
  //
  // centers all servos to center of range
  // defaults to 90deg
  //
  // eg. array.center();

  array.center();


  // min()
  //
  // set all servos to the minimum degrees
  // defaults to 0
  //
  // eg. array.min();

  // max()
  //
  // set all servos to the maximum degrees
  // defaults to 180
  //
  // eg. array.max();

  // move( deg )
  //
  // set all servos to deg
  //
  // eg. array.move( deg );

  // stop()
  //
  // stop all servos
  //
  // eg. array.stop();

  // each( callbackFn )
  //
  // Execute callbackFn for each active servo instance
  //
  // eg.
  // array.each(function( servo, index ) {
  //
  //  `this` refers to the current servo instance
  //
  // });

});

```

## Breadboard




## Documentation

_(Nothing yet)_









## Contributing
All contributions must adhere to the the [Idiomatic.js Style Guide](https://github.com/rwldrn/idiomatic.js),
by maintaining the existing coding style. Add unit tests for any new or changed functionality. Lint and test your code using [grunt](https://github.com/cowboy/grunt).

## Release History
_(Nothing yet)_

## License
Copyright (c) 2012 Rick Waldron <waldron.rick@gmail.com>
Licensed under the MIT license.
